# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.apply_tags import ApplyTags
from whisparr.models.movie_status_type import MovieStatusType
from typing import Optional, Set
from typing_extensions import Self

class MovieEditorResource(BaseModel):
    """
    MovieEditorResource
    """ # noqa: E501
    movie_ids: Optional[List[StrictInt]] = Field(default=None, alias="movieIds")
    monitored: Optional[StrictBool] = None
    quality_profile_id: Optional[StrictInt] = Field(default=None, alias="qualityProfileId")
    minimum_availability: Optional[MovieStatusType] = Field(default=None, alias="minimumAvailability")
    root_folder_path: Optional[StrictStr] = Field(default=None, alias="rootFolderPath")
    tags: Optional[List[StrictInt]] = None
    apply_tags: Optional[ApplyTags] = Field(default=None, alias="applyTags")
    move_files: Optional[StrictBool] = Field(default=None, alias="moveFiles")
    delete_files: Optional[StrictBool] = Field(default=None, alias="deleteFiles")
    add_import_exclusion: Optional[StrictBool] = Field(default=None, alias="addImportExclusion")
    __properties: ClassVar[List[str]] = ["movieIds", "monitored", "qualityProfileId", "minimumAvailability", "rootFolderPath", "tags", "applyTags", "moveFiles", "deleteFiles", "addImportExclusion"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MovieEditorResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if movie_ids (nullable) is None
        # and model_fields_set contains the field
        if self.movie_ids is None and "movie_ids" in self.model_fields_set:
            _dict['movieIds'] = None

        # set to None if monitored (nullable) is None
        # and model_fields_set contains the field
        if self.monitored is None and "monitored" in self.model_fields_set:
            _dict['monitored'] = None

        # set to None if quality_profile_id (nullable) is None
        # and model_fields_set contains the field
        if self.quality_profile_id is None and "quality_profile_id" in self.model_fields_set:
            _dict['qualityProfileId'] = None

        # set to None if root_folder_path (nullable) is None
        # and model_fields_set contains the field
        if self.root_folder_path is None and "root_folder_path" in self.model_fields_set:
            _dict['rootFolderPath'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MovieEditorResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "movieIds": obj.get("movieIds"),
            "monitored": obj.get("monitored"),
            "qualityProfileId": obj.get("qualityProfileId"),
            "minimumAvailability": obj.get("minimumAvailability"),
            "rootFolderPath": obj.get("rootFolderPath"),
            "tags": obj.get("tags"),
            "applyTags": obj.get("applyTags"),
            "moveFiles": obj.get("moveFiles"),
            "deleteFiles": obj.get("deleteFiles"),
            "addImportExclusion": obj.get("addImportExclusion")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.quality import Quality
from typing import Optional, Set
from typing_extensions import Self

class QualityProfileQualityItemResource(BaseModel):
    """
    QualityProfileQualityItemResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    quality: Optional[Quality] = None
    items: Optional[List[QualityProfileQualityItemResource]] = None
    allowed: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["id", "name", "quality", "items", "allowed"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QualityProfileQualityItemResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item in self.items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['items'] = _items
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if items (nullable) is None
        # and model_fields_set contains the field
        if self.items is None and "items" in self.model_fields_set:
            _dict['items'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QualityProfileQualityItemResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "quality": Quality.from_dict(obj["quality"]) if obj.get("quality") is not None else None,
            "items": [QualityProfileQualityItemResource.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "allowed": obj.get("allowed")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
QualityProfileQualityItemResource.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from typing import Optional, Set
from typing_extensions import Self

class RemotePathMappingResource(BaseModel):
    """
    RemotePathMappingResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    host: Optional[StrictStr] = None
    remote_path: Optional[StrictStr] = Field(default=None, alias="remotePath")
    local_path: Optional[StrictStr] = Field(default=None, alias="localPath")
    __properties: ClassVar[List[str]] = ["id", "host", "remotePath", "localPath"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RemotePathMappingResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if host (nullable) is None
        # and model_fields_set contains the field
        if self.host is None and "host" in self.model_fields_set:
            _dict['host'] = None

        # set to None if remote_path (nullable) is None
        # and model_fields_set contains the field
        if self.remote_path is None and "remote_path" in self.model_fields_set:
            _dict['remotePath'] = None

        # set to None if local_path (nullable) is None
        # and model_fields_set contains the field
        if self.local_path is None and "local_path" in self.model_fields_set:
            _dict['localPath'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RemotePathMappingResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "host": obj.get("host"),
            "remotePath": obj.get("remotePath"),
            "localPath": obj.get("localPath")
        })
        return _obj


